from pychart import *
import chartdemo

theme.getopt()
orgdata = chart_data.read_csv("lines.csv")
data=[]

for t in orgdata:
    data.append((t[0], t[1], t[1]*0.05, t[1] * 0.1))

ar = area.T(x_axis=axis.X(label="X", format="/a-30{}%d", tic_interval=20),
            y_axis = axis.Y())


ar.add_plot(line_plot.T(data=data, tick_mark=tick_mark.blackcircle1,
			error_bar = error_bar.bar4, 
			y_error_minus_col=2, y_qerror_minus_col=3,
                        line_style=None))
ar.draw()

